# ✨ awesome-panel

[![PyPI version](https://badge.fury.io/py/awesome-panel.svg)](https://pypi.org/project/awesome-panel/)
[![Downloads](https://pepy.tech/badge/awesome-panel/month)](https://pepy.tech/project/awesome-panel)
![Python Versions](https://img.shields.io/badge/python-3.9%20%7C%203.10-blue)
[![License](https://img.shields.io/badge/License-MIT%202.0-blue.svg)](https://opensource.org/licenses/MIT)
![Test Results](https://github.com/awesome-panel/awesome-panel/actions/workflows/tests.yaml/badge.svg?branch=main)

We want to

- show how awesome [Panel](https://awesome-panel.org) is and push the framework forward.

We provide

- The [awesome-panel.org](https://awesome-panel.org) web site including galleries of
  - [Awesome Panel Applications](https://awesome-panel.org/gallery) and
  - [Awesome Community Resources](https://awesome-panel.org/awesome_list)
- [Youtube Videos](https://www.youtube.com/playlist?list=PLrrcIlm1vLr69f4CsTlrO0wSNBw6VbsJA).
- [Blog Posts](https://medium.com/@marcskovmadsen)
- Communication on social media: [Twitter](https://twitter.com/home) | [LinkedIn](https://www.linkedin.com/in/marcskovmadsen/)
- [Panel Extensions and Example Repositories](https://github.com/orgs/awesome-panel/repositories)

![Awesome Panel Intro](https://github.com/awesome-panel/awesome-panel/blob/master/assets/videos/awesome-panel-intro.gif?raw=true)

## 🚀 Get started in under a minute

Install `awesome-panel` including the *`examples` dependencies*.

```bash
pip install awesome-panel[examples]
```

Explore the sample apps by running

```bash
pn hello awesome-panel
```

and opening [http://localhost:5007/gallery](http://localhost:5007/gallery) in your browser.

You can find the sample apps in the `examples/awesome-panel/awesome-panel` folder.

### 😅 Install geopandas on windows

On Windows you unfortunately have to install the [geopandas](https://geopandas.org/en/stable/) package your self as described in [using-geopandas-windows](https://geoffboeing.com/2014/09/using-geopandas-windows/). This is only required to be able to explore a small subset of the applications.

## 📒 Explore the examples online

Click one of the buttons

[![nbviewer](https://raw.githubusercontent.com/jupyter/design/master/logos/Badges/nbviewer_badge.svg)](https://nbviewer.org/github/awesome-panel/awesome-panel/tree/main/examples/)
[![Binder](https://mybinder.org/badge_logo.svg)](https://mybinder.org/v2/gh/awesome-panel/awesome-panel/HEAD)

## ⭐ Support

Please support [Panel](https://panel.holoviz.org) and
[awesome-panel](https://awesome-panel.org) by giving the projects a star on Github:

- [holoviz/panel](https://github.com/holoviz/panel).
- [awesome-panel/awesome-panel](https://github.com/awesome-panel/awesome-panel).

Thanks

## ❤️ Contribute

If you are looking to contribute to this project you can find ideas in the [issue tracker](https://github.com/awesome-panel/awesome-panel/issues). To get started check out the [DEVELOPER_GUIDE](DEVELOPER_GUIDE.md).

I would love to support and receive your contributions. Thanks.

[![Hacktober Fest](https://github.blog/wp-content/uploads/2022/10/hacktoberfestbanner.jpeg?fit=1200%2C630)](https://github.com/awesome-panel/awesome-panel/issues).
